@@ -1,6 +1,6 @@
 package Net::HTTP;
 
-# $Id: HTTP.pm,v 1.33 2001/08/02 23:30:44 gisle Exp $
+# $Id: HTTP.pm,v 1.35 2001/08/28 04:08:33 gisle Exp $
 
 require 5.005;  # 4-arg substr
 
@@ -35,7 +35,7 @@ sub configure {
     $peer_http_version = "1.0" unless defined $peer_http_version;
     my $send_te = delete $cnf->{SendTE};
 
-    my $sock = $self->SUPER::configure($cnf);
+    my $sock = $self->_http_socket_configure($cnf);
     if ($sock) {
 	unless ($host =~ /:/) {
 	    my $p = $sock->peerport;
@@ -52,6 +52,11 @@ sub configure {
     return $sock;
 }
 
+sub _http_socket_configure {
+    my $self = shift;
+    $self->SUPER::configure(@_);
+}
+
 sub host {
     my $self = shift;
     my $old = ${*$self}{'http_host'};
@@ -193,10 +198,6 @@ sub write_chunk_eof {
     print $self $self->format_chunk_eof(@_);
 }
 
-sub xread {
-    sysread($_[0], $_[1], $_[2], $_[3] || 0);
-}
-
 
 sub my_read {
     die if @_ > 3;
@@ -208,7 +209,7 @@ sub my_read {
 	    return length($_[0]);
 	}
 	else {
-	    return $self->xread($_[0], $len);
+	    return $self->sysread($_[0], $len);
 	}
     }
 }
@@ -221,7 +222,7 @@ sub my_readline {
 	while (1) {
 	    $pos = index($_, "\012");
 	    last if $pos >= 0;
-	    my $n = $self->xread($_, 1024, length);
+	    my $n = $self->sysread($_, 1024, length);
 	    if (!$n) {
 		return undef unless length;
 		return substr($_, 0, length, "");
@@ -652,10 +653,8 @@ Returns the number of bytes in the read buffer.
 =head1 SUBCLASSING
 
 The read_response_headers() and read_entity_body() will invoke the
-method xread() when they need more data.  This method takes the same
-arguments as sysread() and the is in fact implemented as a call to
-sysread().  Subclasses might want to override this method to contol
-how reading takes place.
+sysread() method when they need more data.  Subclasses might want to
+override this method to contol how reading takes place.
 
 The object itself is a glob.  Subclasses should avoid using hash key
 names prefixed with C<http_> and C<io_>.
